# Lattice iCE40

The {py:mod}`torii.platform.vendor.lattice.ice40` module provides a base platform to support Lattice iCE40 devices with the [IceStorm] and [iCECube2] toolchains.

```{eval-rst}

.. autoclass:: torii.platform.vendor.lattice.ice40.ICE40Platform

```

[IceStorm]: https://github.com/YosysHQ/icestorm
[iCECube2]: https://www.latticesemi.com/iCEcube2
